pyparsing.pyparsing.QuotedString

Package pyparsing :: Module pyparsing :: Class QuotedString |
[frames | no frames]

## Type QuotedString

       object --+
                |
    ParserElement --+
                    |
                Token --+
                        |
                       QuotedString

Token for matching strings that are delimited by quoting characters.

Method Summary
| ``__init__`(self, quoteChar, escChar, escQuote, multiline, unquoteResults, endQuoteChar)` Defined with the following parameters:
| `__str__(self)`
| `parseImpl(self, instring, loc, doActions)`
Inherited from `Token`: `setName` Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__getattr__`, `__invert__`, `__mul__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__ror__`, `__rxor__`, `__xor__`, `addParseAction`, `checkRecursion`, `copy`, `enablePackrat`, `getException`, `ignore`, `leaveWhitespace`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `resetCache`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `streamline`, `suppress`, `transformString`, `tryParse`, `validate` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Instance Method Details

### __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False, unquoteResults=True, endQuoteChar=None) (Constructor) Defined with the following parameters: quoteChar - string of one or more characters defining the quote delimiting string escChar - character to escape quotes, typically backslash (default=None) escQuote - special quote sequence to escape an embedded quote string (such as SQL's "" to escape an embedded ") (default=None) multiline - boolean indicating whether quotes can span multiple lines (default=False) unquoteResults - boolean indicating whether the matched text should be unquoted (default=True) endQuoteChar - string of one or more characters defining the end of the quote delimited string (default=None => same as quoteChar) Overrides: `pyparsing.pyparsing.Token.__init__`

Generated by Epydoc 2.1 on Sun Feb 10 18:01:06 2008 | http://epydoc.sf.net